##
##  xmlsec.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2023 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         xmlsec
Summary:      XML Security Library
URL:          http://www.aleksey.com/xmlsec/
Vendor:       Aleksey Sanin
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        BASE
Group:        XML
License:      MIT
Version:      1.3.2
Release:      20231102

#   list of sources
Source0:      http://www.aleksey.com/xmlsec/download/xmlsec1-%{version}.tar.gz

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, libtool
PreReq:       OpenPKG, openpkg >= 20160101
BuildPreReq:  libxml, libxslt, openssl
PreReq:       libxml, libxslt, openssl

%description
    XML Security Library is a companion C library to LibXML, supporting
    the major XML security standards: XML Signature, XML Encryption,
    Canonical XML, Exclusive Canonical XML.

%track
    prog xmlsec = {
        version   = %{version}
        url       = http://www.aleksey.com/xmlsec/download.html
        regex     = xmlsec1-(__VER__)\.tar\.gz
    }

%prep
    %setup -q -n xmlsec1-%{version}
    %{l_shtool} subst \
        -e '/LINENO: error: C[+]* preprocessor/{N;N;N;N;s/.*/:/;}' \
        configure

%build
    CC="%{l_cc}" \
    CFLAGS="%{l_cflags -O}" \
    CPPFLAGS="%{l_cppflags openssl .}" \
    LDFLAGS="%{l_ldflags}" \
    ./configure \
        --prefix=%{l_prefix} \
        --mandir=%{l_prefix}/man \
        --with-libxml=%{l_prefix} \
        --with-libxslt=%{l_prefix} \
        --with-openssl=%{l_prefix} \
        --without-nss \
        --without-nspr \
        --disable-shared
    %{l_make} %{l_mflags -O}

%install
    %{l_make} %{l_mflags} install AM_MAKEFLAGS="DESTDIR=$RPM_BUILD_ROOT"
    rm -rf $RPM_BUILD_ROOT%{l_prefix}/share/doc
    strip $RPM_BUILD_ROOT%{l_prefix}/bin/* >/dev/null 2>&1 || true
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT \
        %{l_files_std}

%files -f files

%clean

